@@ -1,7 +1,7 @@
 package Business::AuthorizeNet::CIM;
 
 BEGIN {
-    $Business::AuthorizeNet::CIM::VERSION = '0.03';
+    $Business::AuthorizeNet::CIM::VERSION = '0.04';
 }
 
 # ABSTRACT: Authorize.Net Customer Information Manager (CIM) Web Services API
@@ -82,7 +82,8 @@ sub createCustomerProfile {
     if ( exists $args->{creditCard} ) {
         $writer->startTag('creditCard');
         foreach my $k ( 'cardNumber', 'expirationDate', 'cardCode' ) {
-            $writer->dataElement( $k, $args->{creditCard}->{$k} );
+            $writer->dataElement( $k, $args->{creditCard}->{$k} )
+              if exists $args->{creditCard}->{$k};
         }
         $writer->endTag('creditCard');
     }
@@ -146,7 +147,7 @@ sub createCustomerPaymentProfileRequest {
     $writer->endTag('merchantAuthentication');
     $writer->dataElement( 'refId', $args->{refId} ) if exists $args->{refId};
     $writer->dataElement( 'customerProfileId', $args->{customerProfileId} );
-    $writer->startTag('paymentProfiles');
+    $writer->startTag('paymentProfile');
     $writer->dataElement( 'customerType', $args->{'customerType'} )
       if exists $args->{'customerType'};
 
@@ -170,7 +171,8 @@ sub createCustomerPaymentProfileRequest {
     if ( exists $args->{creditCard} ) {
         $writer->startTag('creditCard');
         foreach my $k ( 'cardNumber', 'expirationDate', 'cardCode' ) {
-            $writer->dataElement( $k, $args->{creditCard}->{$k} );
+            $writer->dataElement( $k, $args->{creditCard}->{$k} )
+              if exists $args->{creditCard}->{$k};
         }
         $writer->endTag('creditCard');
     }
@@ -188,7 +190,7 @@ sub createCustomerPaymentProfileRequest {
     }
 
     $writer->endTag('payment');
-    $writer->endTag('paymentProfiles');
+    $writer->endTag('paymentProfile');
 
     if ( $self->{test_mode} ) {
         $writer->dataElement( 'validationMode', 'testMode' );
@@ -382,10 +384,6 @@ sub deleteCustomerProfile {
     $writer->dataElement( 'transactionKey', $self->{transactionKey} );
     $writer->endTag('merchantAuthentication');
     $writer->dataElement( 'customerProfileId', $customerProfileId );
-
-    if ( $self->{test_mode} ) {
-        $writer->dataElement( 'validationMode', 'testMode' );
-    }
     $writer->endTag('deleteCustomerProfileRequest');
 
     $xml = '<?xml version="1.0" encoding="utf-8"?>' . "\n" . $xml;
@@ -645,7 +643,8 @@ sub updateCustomerPaymentProfile {
     if ( exists $args->{creditCard} ) {
         $writer->startTag('creditCard');
         foreach my $k ( 'cardNumber', 'expirationDate', 'cardCode' ) {
-            $writer->dataElement( $k, $args->{creditCard}->{$k} );
+            $writer->dataElement( $k, $args->{creditCard}->{$k} )
+              if exists $args->{creditCard}->{$k};
         }
         $writer->endTag('creditCard');
     }
@@ -803,7 +802,7 @@ Business::AuthorizeNet::CIM - Authorize.Net Customer Information Manager (CIM) W
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
